==> nextcloud-23.0.8.tgz: nextcloud/apps/activity/l10n/km.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "បានចម្លង",
    "Press ⌘-C to copy." : " ចុច ⌘-C ដើម្បីចម្លង",
    "Press Ctrl-C to copy." : "ចុច Ctrl-C ដើម្បីចម្លង",
    "{name} (invisible)" : "{name} (ដែលមើលមិនឃើញ)",
    "{name} (restricted)" : "{name} (ដែលហាមឃាត់)",
    "Home" : "ទំព័រដើម",
    "in {path}" : "ក្នុង {path}",
    "There are no events for this filter" : "គ្មានព្រឹត្តិការណ៍សម្រាប់ចម្រោះនេះ",
    "Today" : "ថ្ងៃ​នេះ",
    "Yesterday" : "ម្សិលមិញ",
    "Open {filename}" : "បើក {filename}",
    "Personal activity feed for %s" : "សកម្មភាព feed ផ្ទាល់​ខ្លួន​សម្រាប់ %s",
    "Your feed URL is invalid" : "feed URL របស់អ្នកគឺមិនត្រឹមត្រូវទេ",
    "Your settings have been updated." : "ការ​កំណត់​របស់​អ្នក​ត្រូវ​បាន​ធ្វើ​បច្ចុប្បន្នភាព។",
    "Settings have been updated." : "ការកំណត់ត្រូវបានធ្វើបច្ចុប្បន្នភាព",
    "Recent activity" : "សកម្មភាពថ្មីៗ",
    "Daily activity summary for %s" : "សកម្មភាពប្រចាំថ្ងៃសង្ខេបសម្រាប់ %s",
    "_and %n more _::_and %n more _" : ["និង %n ទៀត"],
    "All activities" : "សកម្មភាពទាំងអស់",
    "By others" : "ដោយអ្នកផ្សេង",
    "By you" : "ដោយអ្នក",
    "Activity at %s" : "សកម្មភាពនៅ %s",
    "Hello %s" : "សួស្ដី %s",
    "Hello %s," : "សួស្ដី %s,",
    "There was some activity at %s" : "មានសកម្មភាពមួយចំនួននៅ %s",
    "Mail" : "សំបុត្រ",
    "Push" : "រុញ",
    "Activity" : "សកម្មភាព",
    "Notifications" : "ការ​ជូន​ដំណឹង",
    "This application enables users to view a log of activities about them or about files." : "កម្មវិធីនេះអនុញ្ញាតឱ្យអ្នកប្រើប្រាស់មើលកំណត់ហេតុនៃសកម្មភាពអំពីពួកគេ ឬអំពីឯកសារផ្សេងៗ។",
    "No activity yet" : "មិនទាន់មានសកម្មភាពអ្វីទេ",
    "Unable to load the activity list" : "មិនអាចទាញយកបញ្ជីសកម្មភាពមកទេ",
    "Activities" : "សកម្មភាពផ្សេងៗ",
    "No activities" : "គ្មានសកម្មភាពទេ",
    "Activity feed" : "សកម្មភាព feed",
    "Enable notification emails" : "អនុញ្ញាតការផ្ដល់ដំណឹងអំពីសារអេឡិចត្រូនិក",
    "Default settings" : "ការកំណត់លំនាំដើម",
    "Configure the default notification settings." : "កែការកំណត់លំនាំដើមនៃការជូនដំណឹង",
    "You need to set up your email address before you can receive notification emails." : "អ្នក​ចាំបាច់​ត្រូវតែដំឡើង​អាសយដ្ឋាន​អ៊ីមែលរបស់អ្នកមុនពេល​ដែលអ្នកអាចទទួលបានការជូន​ដំណឹង​ទៅកាន់​អ៊ីមែល ។",
    "Send activity emails:" : "ផ្ញើអ៊ីម៉ែលអំពីសកម្មភាព",
    "As soon as possible" : "កាន់តែឆាប់តាមដែលអាចធ្វើបាន",
    "Hourly" : "រាល់​ម៉ោង",
    "Daily" : "រាល់ថ្ងៃ",
    "Weekly" : "រាល់​សប្ដាហ៍",
    "Choose for which activities you want to get an email or push notification." : "ជ្រើសរើសថាតើអ្នកចង់ទទួលបានដំណឹងអំពីសកម្មភាពអ្វីខ្លះតាមរយៈអ៊ីម៉ែល ឬ Push Notification ។",
    "Choose for which activities you want to get a push notification." : "ជ្រើសរើសថាតើអ្នកចង់ទទួលបានដំណឹងអំពីសកម្មភាពអ្វីខ្លះតាមរយៈ Push Notification ។",
    "Daily activity summary" : "សង្ខេបនៃសកម្មភាពប្រចាំថ្ងៃ",
    "Send daily activity summary in the morning" : "ផ្ញើសង្ខេបនៃសកម្មភាពប្រចាំថ្ងៃនៅពេលព្រឹក",
    "Enable RSS feed" : "អនុញ្ញាត RSS feed",
    "RSS feed" : "RSS feed",
    "Personal notification settings" : "ការកំណត់ផ្ទាល់ខ្លួនលើការជូនដំណឹង",
    "No more events to load" : "គ្មាន​ព្រឹត្តិការណ៍​ច្រើនទៀតសម្រាប់ទាញយកមកទេ",
    "Activity notification for %s" : "ការជូនដំណឹងអំពីសកម្មភាពសម្រាប់ %s",
    "Send notification emails:" : "ផ្ញើអ៊ីម៉ែលជូនដំណឹង",
    "Settings" : "ការកំណត់",
    "Personal Activity Settings" : "ការកំណត់ «សកម្មភាពផ្ទាល់ខ្លួន»",
    "activities" : "សកម្មភាពផ្សេងៗ"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/activity/l10n/km.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "បានចម្លង",
    "Press ⌘-C to copy." : " ចុច ⌘-C ដើម្បីចម្លង",
    "Press Ctrl-C to copy." : "ចុច Ctrl-C ដើម្បីចម្លង",
    "{name} (invisible)" : "{name} (ដែលមើលមិនឃើញ)",
    "{name} (restricted)" : "{name} (ដែលហាមឃាត់)",
    "Home" : "ទំព័រដើម",
    "in {path}" : "ក្នុង {path}",
    "There are no events for this filter" : "គ្មានព្រឹត្តិការណ៍សម្រាប់ចម្រោះនេះ",
    "Today" : "ថ្ងៃ​នេះ",
    "Yesterday" : "ម្សិលមិញ",
    "Open {filename}" : "បើក {filename}",
    "Personal activity feed for %s" : "សកម្មភាព feed ផ្ទាល់​ខ្លួន​សម្រាប់ %s",
    "Your feed URL is invalid" : "feed URL របស់អ្នកគឺមិនត្រឹមត្រូវទេ",
    "Your settings have been updated." : "ការ​កំណត់​របស់​អ្នក​ត្រូវ​បាន​ធ្វើ​បច្ចុប្បន្នភាព។",
    "Settings have been updated." : "ការកំណត់ត្រូវបានធ្វើបច្ចុប្បន្នភាព",
    "Recent activity" : "សកម្មភាពថ្មីៗ",
    "Daily activity summary for %s" : "សកម្មភាពប្រចាំថ្ងៃសង្ខេបសម្រាប់ %s",
    "_and %n more _::_and %n more _" : ["និង %n ទៀត"],
    "All activities" : "សកម្មភាពទាំងអស់",
    "By others" : "ដោយអ្នកផ្សេង",
    "By you" : "ដោយអ្នក",
    "Activity at %s" : "សកម្មភាពនៅ %s",
    "Hello %s" : "សួស្ដី %s",
    "Hello %s," : "សួស្ដី %s,",
    "There was some activity at %s" : "មានសកម្មភាពមួយចំនួននៅ %s",
    "Mail" : "សំបុត្រ",
    "Push" : "រុញ",
    "Activity" : "សកម្មភាព",
    "Notifications" : "ការ​ជូន​ដំណឹង",
    "Send email" : "ផ្ញើ​អ៊ីមែល",
    "You need to set up your email address before you can receive notification emails." : "អ្នក​ចាំបាច់​ត្រូវតែដំឡើង​អាសយដ្ឋាន​អ៊ីមែលរបស់អ្នកមុនពេល​ដែលអ្នកអាចទទួលបានការជូន​ដំណឹង​ទៅកាន់​អ៊ីមែល ។",
    "As soon as possible" : "កាន់តែឆាប់តាមដែលអាចធ្វើបាន",
    "Hourly" : "រាល់​ម៉ោង",
    "Daily" : "រាល់ថ្ងៃ",
    "Weekly" : "រាល់​សប្ដាហ៍",
    "No activity yet" : "មិនទាន់មានសកម្មភាពអ្វីទេ",
    "Unable to load the activity list" : "មិនអាចទាញយកបញ្ជីសកម្មភាពមកទេ",
    "Enable notification emails" : "អនុញ្ញាតការផ្ដល់ដំណឹងអំពីសារអេឡិចត្រូនិក",
    "Choose for which activities you want to get an email or push notification." : "ជ្រើសរើសថាតើអ្នកចង់ទទួលបានដំណឹងអំពីសកម្មភាពអ្វីខ្លះតាមរយៈអ៊ីម៉ែល ឬ Push Notification ។",
    "Choose for which activities you want to get a push notification." : "ជ្រើសរើសថាតើអ្នកចង់ទទួលបានដំណឹងអំពីសកម្មភាពអ្វីខ្លះតាមរយៈ Push Notification ។",
    "Daily activity summary" : "សង្ខេបនៃសកម្មភាពប្រចាំថ្ងៃ",
    "Send daily activity summary in the morning" : "ផ្ញើសង្ខេបនៃសកម្មភាពប្រចាំថ្ងៃនៅពេលព្រឹក",
    "Activities" : "សកម្មភាពផ្សេងៗ",
    "No activities" : "គ្មានសកម្មភាពទេ",
    "Default settings" : "ការកំណត់លំនាំដើម",
    "Activity feed" : "សកម្មភាព feed",
    "Enable RSS feed" : "អនុញ្ញាត RSS feed",
    "RSS feed" : "RSS feed",
    "Personal notification settings" : "ការកំណត់ផ្ទាល់ខ្លួនលើការជូនដំណឹង",
    "No more events to load" : "គ្មាន​ព្រឹត្តិការណ៍​ច្រើនទៀតសម្រាប់ទាញយកមកទេ",
    "Activity notification for %s" : "ការជូនដំណឹងអំពីសកម្មភាពសម្រាប់ %s",
    "This application enables users to view a log of activities about them or about files." : "កម្មវិធីនេះអនុញ្ញាតឱ្យអ្នកប្រើប្រាស់មើលកំណត់ហេតុនៃសកម្មភាពអំពីពួកគេ ឬអំពីឯកសារផ្សេងៗ។",
    "activities" : "សកម្មភាពផ្សេងៗ",
    "Configure the default notification settings." : "កែការកំណត់លំនាំដើមនៃការជូនដំណឹង",
    "Send activity emails:" : "ផ្ញើអ៊ីម៉ែលអំពីសកម្មភាព",
    "Settings" : "ការកំណត់"
},
"nplurals=1; plural=0;");
